==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/azuredatatransfer/kotlin/inputs/PlanArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azuredatatransfer.kotlin.inputs

import com.pulumi.azurenative.azuredatatransfer.inputs.PlanArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Plan for the resource.
 * @property name A user defined name of the 3rd Party Artifact that is being procured.
 * @property product The 3rd Party artifact that is being procured. E.g. NewRelic. Product maps to the OfferID specified for the artifact at the time of Data Market onboarding.
 * @property promotionCode A publisher provided promotion code as provisioned in Data Market for the said product/artifact.
 * @property publisher The publisher of the 3rd Party Artifact that is being bought. E.g. NewRelic
 * @property version The version of the desired product/artifact.
 */
public data class PlanArgs(
    public val name: Output<String>,
    public val product: Output<String>,
    public val promotionCode: Output<String>? = null,
    public val publisher: Output<String>,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azuredatatransfer.inputs.PlanArgs> {
    override fun toJava(): com.pulumi.azurenative.azuredatatransfer.inputs.PlanArgs =
        com.pulumi.azurenative.azuredatatransfer.inputs.PlanArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .product(product.applyValue({ args0 -> args0 }))
            .promotionCode(promotionCode?.applyValue({ args0 -> args0 }))
            .publisher(publisher.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PlanArgs].
 */
@PulumiTagMarker
public class PlanArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var product: Output<String>? = null

    private var promotionCode: Output<String>? = null

    private var publisher: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value A user defined name of the 3rd Party Artifact that is being procured.
     */
    @JvmName("bbkxydlwcwdggyds")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The 3rd Party artifact that is being procured. E.g. NewRelic. Product maps to the OfferID specified for the artifact at the time of Data Market onboarding.
     */
    @JvmName("bkkjdhhfbaymdfme")
    public suspend fun product(`value`: Output<String>) {
        this.product = value
    }

    /**
     * @param value A publisher provided promotion code as provisioned in Data Market for the said product/artifact.
     */
    @JvmName("qgojfbvwkouprpcm")
    public suspend fun promotionCode(`value`: Output<String>) {
        this.promotionCode = value
    }

    /**
     * @param value The publisher of the 3rd Party Artifact that is being bought. E.g. NewRelic
     */
    @JvmName("dmxadxmjykluhmqq")
    public suspend fun publisher(`value`: Output<String>) {
        this.publisher = value
    }

    /**
     * @param value The version of the desired product/artifact.
     */
    @JvmName("vrcrscgbfrrbkper")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value A user defined name of the 3rd Party Artifact that is being procured.
     */
    @JvmName("yhknmnshqddxrmyi")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The 3rd Party artifact that is being procured. E.g. NewRelic. Product maps to the OfferID specified for the artifact at the time of Data Market onboarding.
     */
    @JvmName("ebroafjtxeikdrxd")
    public suspend fun product(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.product = mapped
    }

    /**
     * @param value A publisher provided promotion code as provisioned in Data Market for the said product/artifact.
     */
    @JvmName("kooufwpybujyflsd")
    public suspend fun promotionCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.promotionCode = mapped
    }

    /**
     * @param value The publisher of the 3rd Party Artifact that is being bought. E.g. NewRelic
     */
    @JvmName("cqrdqjjvbftfovij")
    public suspend fun publisher(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publisher = mapped
    }

    /**
     * @param value The version of the desired product/artifact.
     */
    @JvmName("xltqlsvhtyrqspvo")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): PlanArgs = PlanArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        product = product ?: throw PulumiNullFieldException("product"),
        promotionCode = promotionCode,
        publisher = publisher ?: throw PulumiNullFieldException("publisher"),
        version = version,
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/azuredatatransfer/kotlin/inputs/PlanArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azuredatatransfer.kotlin.inputs

import com.pulumi.azurenative.azuredatatransfer.inputs.PlanArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Plan for the resource.
 * @property name A user defined name of the 3rd Party Artifact that is being procured.
 * @property product The 3rd Party artifact that is being procured. E.g. NewRelic. Product maps to the OfferID specified for the artifact at the time of Data Market onboarding.
 * @property promotionCode A publisher provided promotion code as provisioned in Data Market for the said product/artifact.
 * @property publisher The publisher of the 3rd Party Artifact that is being bought. E.g. NewRelic
 * @property version The version of the desired product/artifact.
 */
public data class PlanArgs(
    public val name: Output<String>,
    public val product: Output<String>,
    public val promotionCode: Output<String>? = null,
    public val publisher: Output<String>,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azuredatatransfer.inputs.PlanArgs> {
    override fun toJava(): com.pulumi.azurenative.azuredatatransfer.inputs.PlanArgs =
        com.pulumi.azurenative.azuredatatransfer.inputs.PlanArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .product(product.applyValue({ args0 -> args0 }))
            .promotionCode(promotionCode?.applyValue({ args0 -> args0 }))
            .publisher(publisher.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PlanArgs].
 */
@PulumiTagMarker
public class PlanArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var product: Output<String>? = null

    private var promotionCode: Output<String>? = null

    private var publisher: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value A user defined name of the 3rd Party Artifact that is being procured.
     */
    @JvmName("cmdkpexquyhidxoy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The 3rd Party artifact that is being procured. E.g. NewRelic. Product maps to the OfferID specified for the artifact at the time of Data Market onboarding.
     */
    @JvmName("xwdtfmeqqmlojftu")
    public suspend fun product(`value`: Output<String>) {
        this.product = value
    }

    /**
     * @param value A publisher provided promotion code as provisioned in Data Market for the said product/artifact.
     */
    @JvmName("xbnvlpeckihfwjpr")
    public suspend fun promotionCode(`value`: Output<String>) {
        this.promotionCode = value
    }

    /**
     * @param value The publisher of the 3rd Party Artifact that is being bought. E.g. NewRelic
     */
    @JvmName("gvpwbosbkorwtqyl")
    public suspend fun publisher(`value`: Output<String>) {
        this.publisher = value
    }

    /**
     * @param value The version of the desired product/artifact.
     */
    @JvmName("pkfvxeqbdvjayxey")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value A user defined name of the 3rd Party Artifact that is being procured.
     */
    @JvmName("dwdyivfmuewmrobu")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The 3rd Party artifact that is being procured. E.g. NewRelic. Product maps to the OfferID specified for the artifact at the time of Data Market onboarding.
     */
    @JvmName("exkpfhytwtlhndgo")
    public suspend fun product(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.product = mapped
    }

    /**
     * @param value A publisher provided promotion code as provisioned in Data Market for the said product/artifact.
     */
    @JvmName("aqninhtloseamdyd")
    public suspend fun promotionCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.promotionCode = mapped
    }

    /**
     * @param value The publisher of the 3rd Party Artifact that is being bought. E.g. NewRelic
     */
    @JvmName("bugygugjgchkhirh")
    public suspend fun publisher(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publisher = mapped
    }

    /**
     * @param value The version of the desired product/artifact.
     */
    @JvmName("wkjdnmnxnhnxbprq")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): PlanArgs = PlanArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        product = product ?: throw PulumiNullFieldException("product"),
        promotionCode = promotionCode,
        publisher = publisher ?: throw PulumiNullFieldException("publisher"),
        version = version,
    )
}
